const locale = {
    " (area: {measure})": "(area: {measure})",
    " (length: {measure})": "(length: {measure})",
    "# one hash for main heading": "# یک هشتگ برای عنوان اصلی",
    "## two hashes for second heading": "## دو هشتگ برای عنوان دوم",
    "### three hashes for third heading": "### سه هشتگ برای عنوان سوم",
    "**double star for bold**": "** دو ستاره برای پررنگ **",
    "*single star for italic*": "*single star for italic*",
    "--- for a horizontal rule": "--- for a horizontal rule",
    "1 day": "1 روز",
    "1 hour": "1 ساعت",
    "5 min": "5 دقیقه",
    "A comma separated list of numbers that defines the stroke dash pattern. Ex.: \"5, 10, 15\".": "لیستی از اعداد جدا شده با کاما که الگوی خط تیره را مشخص می کند. مثال: \"5 ، 10 ، 15\".",
    "About": "درباره",
    "Action not allowed :(": "Action not allowed :(",
    "Activate slideshow mode": "حالت نمایش اسلاید را فعال کنید",
    "Add a layer": "یک لایه اضافه کنید",
    "Add a line to the current multi": "یک خط به مولتی فعلی اضافه کنید",
    "Add a new property": "یک ویژگی جدید اضافه کنید",
    "Add a polygon to the current multi": "چند ضلعی را به مولتی فعلی اضافه کنید",
    "Add image URL": "Add image URL",
    "Add": "Add",
    "Advanced actions": "اقدامات پیشرفته",
    "Advanced properties": "خواص پیشرفته",
    "All data and settings of the map": "All data and settings of the map",
    "All properties are imported.": "همه املاک وارد شده است",
    "Allow interactions": "اجازه تعامل دهید",
    "Allow scroll wheel zoom?": "زوم با چرخانک موشواره مجاز باشد؟",
    "always": "همیشه",
    "Animated transitions": "Animated transitions",
    "Are you sure you want to cancel your changes?": "آیا مطمئن هستید که می خواهید تغییرات خود را لغو کنید؟",
    "Are you sure you want to clone this map and all its datalayers?": "آیا مطمئن هستید که می خواهید این نقشه و همه فهرست داده های آن را شبیه سازی کنید؟",
    "Are you sure you want to delete the feature?": "آیا مطمئن هستید که می خواهید ویژگی را حذف کنید؟",
    "Are you sure you want to delete this layer?": "آیا مطمئن هستید که می خواهید این لایه را حذف کنید؟",
    "Are you sure you want to delete this map?": "آیا مطمئن هستید که می خواهید این نقشه را حذف کنید؟",
    "Are you sure you want to delete this property on all the features?": "آیا مطمئن هستید که می خواهید این ویژگی را در همه ویژگی ها حذف کنید؟",
    "Are you sure you want to restore this version?": "آیا مطمئن هستید که می خواهید این نسخه را بازیابی کنید؟",
    "Attach the map to my account": "نقشه را به حساب من وصل کنید",
    "attribution": "انتساب",
    "Auto": "خودکار",
    "Automatic": "خودکار",
    "Autostart when map is loaded": "هنگام بارگیری، نقشه خودکار را راه اندازی کنید",
    "Back to preview": "Back to preview",
    "Background overlay url": "Background overlay url",
    "Ball": "توپ",
    "Bring feature to center": "Bring feature to center",
    "Browse data": "مرور داده ها",
    "by": "بوسیله",
    "Cache proxied request": "درخواست پراکسی حافظه پنهان",
    "Cancel edits": "لغو ویرایش ها",
    "Cancel": "انصراف",
    "Caption": "درباره",
    "Center map on your location": "نقشه مرکز بر روی موقعیت مکانی شما",
    "Change map background": "تغییر پس زمینه نقشه",
    "Change tilelayers": "کاشی های کاری را تغییر دهید",
    "Change": "Change",
    "Choose a preset": "از پیش تعیین شده را انتخاب کنید",
    "Choose the data format": "قالب داده را انتخاب کنید",
    "Choose the format of the data to import": "قالب داده را برای وارد کردن انتخاب کنید",
    "Choose the layer to import in": "لایه ای را برای وارد کردن انتخاب کنید",
    "Choropleth breakpoints": "Choropleth breakpoints",
    "Choropleth classes": "Choropleth classes",
    "Choropleth color palette": "Choropleth color palette",
    "Choropleth mode": "Choropleth mode",
    "Choropleth property value": "Choropleth property value",
    "Choropleth": "Choropleth",
    "Circle": "دایره",
    "clear": "روشن/شفاف",
    "Click last point to finish shape": "برای پایان دادن به شکل روی آخرین نقطه کلیک کنید",
    "Click to add a marker": "برای افزودن نشانگر کلیک کنید",
    "Click to continue drawing": "برای ادامه ترسیم کلیک کنید",
    "Click to edit": "برای ویرایش کلیک کنید",
    "Click to start drawing a line": "برای شروع رسم خط کلیک کنید",
    "Click to start drawing a polygon": "برای شروع ترسیم چند ضلعی کلیک کنید",
    "Clone of {name}": "شبیه سازی {name}",
    "Clone this feature": "این ویژگی را شبیه سازی کنید",
    "Clone this map": "شبیه سازی این نقشه",
    "Clone": "شبیه سازی / کلون",
    "Close": "بستن",
    "Clustered": "خوشه‌ای",
    "Clustering radius": "شعاع خوشه بندی",
    "collapsed": "فرو ریخت",
    "color": "رنگ",
    "Comma separated list of numbers, including min and max values.": "Comma separated list of numbers, including min and max values.",
    "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.": "Comma separated list of properties to use for sorting features. To reverse the sort, put a minus sign (-) before. Eg. mykey,-otherkey.",
    "Comma separated list of properties to use when filtering features": "لیستی از خواص جدا شده با کاما برای فیلتر کردن ویژگی ها",
    "Comma, tab or semi-colon separated values. SRS WGS84 is implied. Only Point geometries are imported. The import will look at the column headers for any mention of «lat» and «lon» at the begining of the header, case insensitive. All other column are imported as properties.": "مقادیر جدا شده با کاما، برگه یا نیمه کولون. SRS WGS84 ضمنی است. فقط هندسه نقطه وارد می شود. واردات به سربرگهای ستون برای ذکر هرگونه عبارت «lat» و «lon» در ابتدای سرصفحه، بدون حساس به حروف، نگاه می کند. همه ستون های دیگر به عنوان ویژگی وارد می شوند.",
    "Congratulations, your map has been created!": "Congratulations, your map has been created!",
    "Continue line (Ctrl+Click)": "ادامه خط (Ctrl+Click)",
    "Continue line": "ادامه خط",
    "Coordinates": "مختصات",
    "Copy link": "Copy link",
    "copy": "copy",
    "Credits": "اعتبار",
    "Current map view": "Current map view",
    "Current view instead of default map view?": "نمای فعلی به جای نمای نقشه پیش فرض؟",
    "Custom background": "پس زمینه سفارشی",
    "Custom overlay": "Custom overlay",
    "dash array": "آرایه خط تیره",
    "Data browser": "مرورگر داده",
    "Data is browsable": "داده ها قابل مرور هستند",
    "Datalayers": "Datalayers",
    "Default interaction options": "گزینه های پیش فرض تعامل",
    "Default properties": "خواص پیش فرض",
    "Default shape properties": "ویژگی های شکل پیش فرض",
    "Default view": "Default view",
    "Default zoom level": "سطح بزرگنمایی پیش فرض",
    "Default": "پیشفرض",
    "Default: name": "پیش فرض: نام",
    "Define link to open in a new window on polygon click.": "پیوندی را باز کنید که در یک پنجره جدید با کلیک چند ضلعی باز می شود.",
    "define": "تعريف كردن",
    "Delay between two transitions when in play mode": "تأخیر بین دو انتقال در حالت پخش",
    "Delete all layers": "حذف همه لایه ها",
    "Delete layer": "حذف لایه",
    "Delete this feature": "این ویژگی را حذف کنید",
    "Delete this property on all the features": "این ویژگی را در همه ویژگی ها حذف کنید",
    "Delete this shape": "این شکل را حذف کنید",
    "Delete this vertex (Alt+Click)": "حذف این راس (Alt+Click)",
    "Delete": "حذف",
    "description": "شرح",
    "Direct link": "Direct link",
    "Directions from here": "مسیرها از اینجا",
    "Display label": "برچسب نمایش",
    "Display measure": "اندازه نمایش",
    "display name": "نام نمایشی",
    "Display on load": "نمایش روی بارگذاری",
    "Display the control to open OpenStreetMap editor": "کنترل را برای باز کردن ویرایشگر اوپن‌استریت‌مپ نمایش دهید",
    "Display the data layers control": "نمایش کنترل لایه های داده",
    "Display the embed control": "نمایش کنترل جاسازی",
    "Display the fullscreen control": "نمایش کنترل تمام صفحه",
    "Display the locate control": "کنترل مکان یابی را نمایش دهید",
    "Display the measure control": "نمایش کنترل اندازه گیری",
    "Display the search control": "نمایش کنترل جستجو",
    "Display the star map button": "Display the star map button",
    "Display the tile layers control": "نمایش لایه های کنترل کاشی",
    "Display the zoom control": "نمایش کنترل زوم",
    "Do you want to display a caption bar?": "آیا می خواهید نوار زیرنویس نشان داده شود؟",
    "Do you want to display a minimap?": "آیا می خواهید حداقل نقشه را نمایش دهید؟",
    "Do you want to display a panel on load?": "آیا می خواهید یک صفحه را در حالت بارگذاری نمایش دهید؟",
    "Do you want to display caption menus?": "آیا می‌خواهید منوهای زیرنویس نشان داده شود؟",
    "Do you want to display popup footer?": "آیا می خواهید پاورقی نمایش داده شود؟",
    "Do you want to display the scale control?": "آیا می خواهید کنترل مقیاس را نمایش دهید؟",
    "Do you want to display the «more» control?": "آیا می خواهید کنترل «بیشتر» را نمایش دهید؟",
    "Download": "دانلود",
    "Drag to reorder": "برای مرتب سازی دیگر بکشید",
    "Draw a marker": "یک نشانگر بکشید",
    "Draw a polygon": "چند ضلعی بکشید",
    "Draw a polyline": "چند خطی بکشید",
    "Drawing": "Drawing",
    "Drop": "رها کردن",
    "Dynamic properties": "خواص پویا",
    "Dynamic": "پویا",
    "Edit feature's layer": "لایه ویژگی را ویرایش کنید",
    "Edit properties in a table": "ویژگی ها را در یک جدول ویرایش کنید",
    "Edit the title of the map": "Edit the title of the map",
    "Edit this feature": "این ویژگی را ویرایش کنید",
    "Edit": "ویرایش",
    "Email": "Email",
    "Embed and link options": "Embed and link options",
    "Embed the map": "نقشه را جاسازی کنید",
    "Emoji & Character": "Emoji & Character",
    "Empty": "خالی",
    "Equidistant": "Equidistant",
    "Error in the overlay URL": "Error in the overlay URL",
    "Error in the tilelayer URL": "خطا در آدرس اینترنتی لایه کاشی",
    "Exit Fullscreen": "خروج از تمام صفحه",
    "expanded": "منبسط",
    "Extract shape to separate feature": "استخراج شکل به ویژگی جدا",
    "Facet keys": "Facet keys",
    "Facet search": "Facet search",
    "Feature identifier key": "کلید شناسایی ویژگی",
    "Feature properties": "Feature properties",
    "Fetch data each time map view changes.": "هر بار که نمای نقشه تغییر می کند، داده ها را واکشی کنید.",
    "fill color": "پر کردن رنگ",
    "fill opacity": "تاری/کِدِری را پر کنید",
    "fill": "پر کردن",
    "Filter keys": "کلیدهای فیلتر",
    "Filter": "Filter",
    "Fit all data": "Fit all data",
    "Format": "قالب",
    "From zoom": "از زوم",
    "full backup": "full backup",
    "Generic": "Generic",
    "GeoRSS (only link)": "GeoRSS (فقط لینک)",
    "GeoRSS (title + image)": "GeoRSS (عنوان + تصویر)",
    "Go to \"{coords}\"": "Go to \"{coords}\"",
    "Go to the homepage": "Go to the homepage",
    "Go to «{feature}»": "به «{ویژگی}» بروید",
    "Heatmap intensity property": "ویژگی شدت حرارت",
    "Heatmap radius": "شعاع نقشه حرارتی",
    "Heatmap": "نقشه حرارت و گرما",
    "height": "ارتفاع",
    "Help": "راهنما",
    "hidden": "پنهان",
    "Hide controls": "مخفی کردن کنترل ها",
    "Home": "خانه",
    "How much to simplify the polyline on each zoom level (more = better performance and smoother look, less = more accurate)": "چقدر می توان چند خطی را در هر سطح بزرگنمایی ساده کرد (بیشتر = عملکرد بهتر و ظاهر صاف، کمتر = دقیق تر)",
    "icon opacity": "icon opacity",
    "Icon shape": "شکل نماد",
    "Icon symbol": "آیکون نماد",
    "If false, the polygon or line will act as a part of the underlying map.": "If false, the polygon or line will act as a part of the underlying map.",
    "Iframe with custom height (in px): {{{http://iframe.url.com|height}}}": "Iframe با ارتفاع سفارشی (بر حسب px):{{{http://iframe.url.com|height}}}",
    "Iframe with custom height and width (in px): {{{http://iframe.url.com|height*width}}}": "iframe با ارتفاع و عرض سفارشی (بر حسب px):{{{http://iframe.url.com|height*width}}}",
    "iframe": "iframe",
    "Iframe: {{{http://iframe.url.com}}}": "Iframe: {{{http://iframe.url.com}}}",
    "Image with custom width (in px): {{http://image.url.com|width}}": "تصویر با عرض سفارشی (بر حسب px): {{http://image.url.com|width}}",
    "Image: {{http://image.url.com}}": "تصویر: {{http://image.url.com}}",
    "Import data": "وارد كردن داده",
    "Import in a new layer": "وارد کردن در یک لایه جدید",
    "Import": "وارد كردن",
    "Imports all umap data, including layers and settings.": "همه داده های umap ، از جمله لایه ها و تنظیمات را وارد می کند.",
    "Include full screen link?": "پیوند تمام صفحه را شامل می شود؟",
    "Inherit": "ارث بری",
    "inherit": "به ارث می برند",
    "Interaction options": "گزینه های تعامل",
    "Invalid latitude or longitude": "طول یا عرض جغرافیایی نامعتبر است",
    "Invalid umap data in {filename}": "داده های umap نامعتبر در {نام فایل}",
    "Invalid umap data": "داده های umap نامعتبر است",
    "Invalide property name: {name}": "نام دارایی معتبر نیست: {name}",
    "Jenks-Fisher": "Jenks-Fisher",
    "K-means": "K-means",
    "Keep current visible layers": "لایه های قابل مشاهده فعلی را حفظ کنید",
    "kilometers": "کیلومتر",
    "km": "کیلومتر",
    "Label direction": "جهت برچسب",
    "Label key": "کلید برچسب",
    "Labels are clickable": "برچسب ها قابل کلیک هستند",
    "Latest feature": "Latest feature",
    "Latitude": "عرض جغرافیایی",
    "Layer properties": "خواص لایه",
    "Layer": "لایه",
    "Licence": "مجوز",
    "licence": "مجوز",
    "Limit bounds": "محدودیت ها را محدود کنید",
    "Link to view the map": "Link to view the map",
    "Link to…": "پیوند به…",
    "Link with text: [[http://example.com|text of the link]]": "پیوند با متن: [[http://example.com|text of the link]]",
    "Long credits": "اعتبارات طولانی",
    "Longitude": "عرض جغرافیایی",
    "Make main shape": "شکل اصلی را ایجاد کنید",
    "Manage layers": "لایه ها را مدیریت کنید",
    "Manual": "Manual",
    "Map background credits": "اعتبار پس زمینه نقشه",
    "Map has been attached to your account": "نقشه به حساب شما پیوست شده است",
    "Map has been saved!": "نقشه ذخیره شد!",
    "Map has been starred": "Map has been starred",
    "Map has been unstarred": "Map has been unstarred",
    "Map user content has been published under licence": "محتوای کاربر نقشه، تحت مجوز منتشر شده است",
    "Map's editors": "ویرایشگران نقشه",
    "Map's owner": "مالک نقشه",
    "max East": "حداکثر شرقی",
    "max North": "حداکثر شمالی",
    "max South": "حداکثر جنوبی",
    "max West": "حداکثر غربی",
    "max zoom": "حداکثر بزرگنمایی",
    "Measure distances": "فاصله ها را اندازه گیری کنید",
    "Merge lines": "ادغام خطوط",
    "mi": "مایل",
    "miles": "مایل ها",
    "min zoom": "حداقل بزرگنمایی",
    "More controls": "کنترل های بیشتر",
    "Must be a valid CSS value (eg.: DarkBlue or #123456)": "باید یک مقدار CSS معتبر باشد (به عنوان مثال: DarkBlue یا #123456)",
    "name": "نام",
    "nautical miles": "مایل دریایی",
    "never": "هرگز",
    "new window": "پنجره جدید",
    "next": "بعد",
    "NM": "NM",
    "No cache": "بدون حافظه پنهان",
    "No licence has been set": "هیچ مجوزی تنظیم نشده است",
    "No results for these facets": "No results for these facets",
    "No results": "بدون نتیجه",
    "no": "نه",
    "No.": "No.",
    "None": "هیچکدام",
    "Number of desired classes (default 5)": "Number of desired classes (default 5)",
    "On the bottom": "در انتها",
    "On the left": "در سمت چپ",
    "On the right": "در سمت راست",
    "On the top": "در بالا",
    "Only visible layers' data": "Only visible layers' data",
    "opacity": "تاری/کِدِری",
    "Opacity": "Opacity",
    "Open current feature on load": "باز کردن ویژگی فعلی هنگام بارگیری",
    "Open link in…": "باز کردن پیوند در…",
    "Open share & download panel": "Open share & download panel",
    "Open this map extent in a map editor to provide more accurate data to OpenStreetMap": "این محدوده نقشه را در ویرایشگر نقشه باز کنید تا داده های دقیق تری در اوپن‌استریت‌مپ ارائه شود",
    "OpenStreetMap": "OpenStreetMap",
    "Optional intensity property for heatmap": "ویژگی های اختیاری شدت برای نقشه حرارتی",
    "Optional. Same as color if not set.": "اختیاری. اگر تنظیم نشده باشد همان رنگ است.",
    "Optional.": "اختیاری.",
    "Override clustering radius (default 80)": "نادیده گرفتن شعاع خوشه بندی (پیش فرض 80)",
    "Override heatmap radius (default 25)": "لغو شعاع نقشه حرارتی (پیش فرض 25)",
    "parent window": "پنجره والدین",
    "Paste your data here": "اطلاعات و داده های خود را اینجا بچسبانید",
    "Permalink": "پیوند ثابت",
    "Permanent credits background": "پیشینه اعتبارات دائمی",
    "Permanent credits": "اعتبارات دائمی",
    "Please be sure the licence is compliant with your use.": "لطفاً مطمئن شوید مجوز با استفاده شما مطابقت دارد.",
    "Please choose a format": "لطفاً یک قالب را انتخاب کنید",
    "Please enter the name of the property": "لطفاً نام ملک را وارد کنید",
    "Please enter the new name of this property": "لطفا نام جدید این ملک را وارد کنید",
    "Please save the map first": "لطفاً ابتدا نقشه را ذخیره کنید",
    "Popup (large)": "پنجره بازشو (بزرگ)",
    "Popup content style": "سبک محتوای بازشو",
    "Popup content template": "قالب محتوای بازشو",
    "Popup shape": "شکل پنجره بازشو",
    "Popup": "پنجره بازشو",
    "Powered by uMap": "Powered by uMap",
    "previous": "قبل",
    "Problem in the response": "Problem in the response",
    "Properties imported:": "خواص وارد شده:",
    "Provide an URL here": "در اینجا آدرس اینترنتی ارائه دهید",
    "Proxy request": "درخواست پروکسی",
    "Quantiles": "Quantiles",
    "Recent": "Recent",
    "Remote data": "داده های از راه دور",
    "Remove shape from the multi": "حذف شکل از مولتی",
    "Rename this property on all the features": "نام این ویژگی را در همه ویژگی ها تغییر دهید",
    "Replace layer content": "جایگزینی محتوای لایه",
    "Restore this version": "این نسخه را بازیابی کنید",
    "Save anyway": "به هر حال ذخیره کنید",
    "Save current edits": "ویرایش های فعلی را ذخیره کنید",
    "Save map": "Save map",
    "Save this center and zoom": "این مرکز را ذخیره کرده و بزرگنمایی کنید",
    "Save this location as new feature": "این مکان را به عنوان ویژگی جدید ذخیره کنید",
    "Save": "ذخیره",
    "Saved center and zoom": "Saved center and zoom",
    "Search location": "مکان را جستجو کنید",
    "Search": "Search",
    "Secret edit link copied to clipboard!": "Secret edit link copied to clipboard!",
    "Secret edit link:": "Secret edit link:",
    "See layers": "See layers",
    "See full screen": "تمام صفحه را مشاهده کنید",
    "See on OpenStreetMap": "See on OpenStreetMap",
    "Select data": "داده‌ها را انتخاب کنید",
    "Send me the link": "Send me the link",
    "Set it to false to hide this layer from the slideshow, the data browser, the popup navigation…": "آن را روی غلط/false تنظیم کنید تا این لایه از نمایش اسلاید، مرورگر داده، ناوبری بازشو پنهان شود…",
    "settings": "settings",
    "Shape properties": "ویژگی های شکل",
    "Share and download": "Share and download",
    "Share this link to open a customized map view": "Share this link to open a customized map view",
    "Short credits": "اعتبار کوتاه مدت",
    "Short link": "Short link",
    "Show this layer in the caption": "Show this layer in the caption",
    "Show/hide layer": "نمایش/مخفی کردن لایه",
    "Side panel": "پنل کناری",
    "Simple link: [[http://example.com]]": "پیوند ساده: [[http://example.com]]",
    "Simplify": "ساده کنید",
    "Skipping unknown geometry.type: {type}": "رد شدن از geometry.type ناشناخته: {نوع}",
    "Slideshow": "نمایش اسلاید",
    "Sort key": "کلید مرتب سازی",
    "Split line": "خط تقسیم",
    "Star this map": "Star this map",
    "Start a hole here": "از اینجا یک حفره شروع کنید",
    "Start slideshow": "شروع نمایش اسلاید",
    "Stop editing": "ویرایش را متوقف کنید",
    "Stop slideshow": "نمایش اسلاید را متوقف کنید",
    "Street": "Street",
    "stroke": "سکته",
    "Supported scheme": "طرح پشتیبانی شده",
    "Supported variables that will be dynamically replaced": "متغیرهای پشتیبانی شده که به صورت پویا جایگزین می شوند",
    "Switch to edit mode": "Switch to edit mode",
    "Symbol": "Symbol",
    "Table": "جدول",
    "Text color for the cluster label": "رنگ متن برای برچسب خوشه",
    "Text formatting": "قالب بندی متن",
    "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")": "The name of the property to use as feature label (eg.: \"nom\"). You can also use properties inside brackets to use more than one or mix with static content (eg.: \"&lcub;name&rcub; in &lcub;place&rcub;\")",
    "The name of the property to use as feature unique identifier.": "نام ویژگی برای استفاده به عنوان شناسه منحصر به فرد ویژگی.",
    "The zoom and center have been modified.": "The zoom and center have been modified.",
    "TMS format": "قالب TMS",
    "To use if remote server doesn't allow cross domain (slower)": "برای استفاده در صورت عدم دسترسی سرور از راه دور به دامنه (کندتر)",
    "To zoom": "زوم",
    "Toggle edit mode (⇧+Click)": "Toggle edit mode (⇧+Click)",
    "Toggle edit mode": "Toggle edit mode",
    "Transfer shape to edited feature": "انتقال شکل به ویژگی ویرایش شده",
    "Transform to lines": "تبدیل به خطوط",
    "Transform to polygon": "تبدیل به چند ضلعی",
    "Type a place name or coordinates": "Type a place name or coordinates",
    "Type char or paste emoji": "Type char or paste emoji",
    "Type of layer": "نوع لایه",
    "Unable to detect format of file {filename}": "تشخیص قالب فایل {نام فایل} امکان پذیر نیست",
    "Untitled layer": "لایه بدون عنوان",
    "Untitled map": "نقشه بدون عنوان",
    "Update permissions and editors": "مجوزها و ویرایشگران را به روز کنید",
    "Update permissions": "مجوزها را به روز کنید",
    "Update who can see and edit the map": "Update who can see and edit the map",
    "Url": "آدرس اینترنتی",
    "URL": "URL",
    "Use current bounds": "از مرزهای فعلی استفاده کنید",
    "Use placeholders with feature properties between brackets, eg. &#123;name&#125;, they will be dynamically replaced by the corresponding values.": "از متغیرهایی با ویژگی های ویژگی بین براکت ها استفاده کنید ، به عنوان مثال. &#123;name&#125;، آنها به طور پویا با مقادیر مربوطه جایگزین می شوند.",
    "User content credits": "اعتبار محتوای کاربر",
    "User interface options": "گزینه های رابط کاربر",
    "User location": "User location",
    "Verify remote URL": "Verify remote URL",
    "Versions": "نسخه ها",
    "View Fullscreen": "مشاهده تمام صفحه",
    "View": "View",
    "Visibility: {status}": "Visibility: {status}",
    "weight": "وزن/سنگینی",
    "Where do we go from here?": "از اینجا به کجا می رویم؟",
    "Whether to display or not polygons paths.": "اینکه آیا مسیرهای چند ضلعی نمایش داده شود یا خیر.",
    "Whether to fill polygons with color.": "این که چند ضلعی ها را با رنگ پر کنیم یا خیر.",
    "Who can edit \"{layer}\"": "Who can edit \"{layer}\"",
    "Who can edit": "چه کسی می تواند ویرایش کند",
    "Who can view": "چه کسی می تواند مشاهده کند",
    "width": "عرض",
    "Will be displayed in the bottom right corner of the map": "در گوشه سمت راست پایین نقشه نمایش داده می شود",
    "Will be permanently visible in the bottom left corner of the map": "برای همیشه در گوشه سمت چپ پایین نقشه قابل مشاهده خواهد بود",
    "Will be visible in the caption of the map": "در زیرنویس نقشه قابل مشاهده خواهد بود",
    "Woops! Someone else seems to have edited the data. You can save anyway, but this will erase the changes made by others.": "وای! به نظر می رسد شخص دیگری داده ها را ویرایش کرده است. در هر صورت می توانید ذخیره کنید، اما با این کار تغییرات ایجاد شده توسط دیگران پاک می شود.",
    "yes": "بله",
    "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:": "Your map has been created! As you are not logged in, here is your secret link to edit the map, please keep it safe:",
    "Zoom in": "بزرگنمایی",
    "Zoom level for automatic zooms": "سطح زوم برای بزرگنمایی خودکار",
    "Zoom out": "کوچک نمایی",
    "Zoom to layer extent": "تا اندازه لایه بزرگنمایی کنید",
    "Zoom to the next": "روی بعدی زوم کنید",
    "Zoom to the previous": "روی قبلی بزرگنمایی کنید",
    "Zoom to this feature": "روی این ویژگی بزرگنمایی کنید",
    "Zoom to this place": "روی این مکان بزرگنمایی کنید",
    "{area}&#8239;acres": "{area} acres",
    "{area}&#8239;ha": "{area} ha",
    "{area}&#8239;m&sup2;": "{area} m&sup2;",
    "{area}&#8239;mi&sup2;": "{area} mi&sup2;",
    "{area}&#8239;yd&sup2;": "{area} yd&sup2;",
    "{count} errors during import: {message}": "{شمردن} خطاها هنگام وارد کردن: {پیام}",
    "{delay} seconds": "{تاخیر} ثانیه",
    "{distance}&#8239;km": "{distance} km",
    "{distance}&#8239;m": "{distance} m",
    "{distance}&#8239;miles": "{distance} miles",
    "{distance}&#8239;NM": "{distance} NM",
    "{distance}&#8239;yd": "{distance} yd",
    "Edit map name and caption": "Edit map name and caption",
    "Map advanced properties": "Map advanced properties",
    "Edit map details": "Edit map details",
    "Back to browser": "Back to browser",
    "Toggle size": "Toggle size",
    "Layers": "Layers",
    "Display the caption control": "Display the caption control",
    "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.": "Comma separated list of properties to use for facet search (eg.: mykey,otherkey). To control label, add it after a | (eg.: mykey|My Key,otherkey|Other Key). To control input field type, add it after another | (eg.: mykey|My Key|checkbox,otherkey|Other Key|datetime). Allowed values for the input field type are checkbox (default), radio, number, date and datetime.",
    "<empty value>": "<empty value>",
    "Min": "Min",
    "Max": "Max",
    "From": "From",
    "Until": "Until",
    "Example: key1,key2|Label 2,key3|Label 3|checkbox": "Example: key1,key2|Label 2,key3|Label 3|checkbox",
    "Edit in OpenStreetMap": "Edit in OpenStreetMap",
    "Cannot determine latitude and longitude columns.": "Cannot determine latitude and longitude columns."
}
L.registerLocale("fa_IR", locale)
L.setLocale("fa_IR")
